"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var types = require("tns-core-modules/utils/types");
var image_asset_1 = require("tns-core-modules/image-asset");
var imageSource = require("tns-core-modules/image-source");
var trace = require("tns-core-modules/trace");
var frame = require("tns-core-modules/ui/frame");
var listener;
var SimpleCamDelegateImpl = (function (_super) {
    __extends(SimpleCamDelegateImpl, _super);
    function SimpleCamDelegateImpl() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SimpleCamDelegateImpl.initWithCallbackAndOptions = function (callback, options) {
        var delegate = SimpleCamDelegateImpl.new();
        delegate.callback = callback;
        if (options) {
            delegate.width = options.width;
            delegate.height = options.height;
            delegate.keepAspectRatio = types.isNullOrUndefined(options.keepAspectRatio) ? true : options.keepAspectRatio;
        }
        return delegate;
    };
    SimpleCamDelegateImpl.prototype.simpleCamNotAuthorizedForCameraUse = function (simpleCam) {
        if (this.callback) {
            this.callback(null);
        }
        simpleCam.closeWithCompletion(function () {
            listener = null;
        });
    };
    SimpleCamDelegateImpl.prototype.simpleCamDidFinishWithImage = function (simpleCam, image) {
        if (image) {
            var imageSourceResult = imageSource.fromNativeSource(image);
            if (this.callback) {
                var imageAsset = new image_asset_1.ImageAsset(imageSourceResult.ios);
                imageAsset.options = {
                    width: this.width,
                    height: this.height,
                    keepAspectRatio: this.keepAspectRatio,
                };
                this.callback(imageAsset);
            }
        }
        simpleCam.closeWithCompletion(function () {
            listener = null;
        });
    };
    SimpleCamDelegateImpl.ObjCProtocols = [SimpleCamDelegate];
    return SimpleCamDelegateImpl;
}(NSObject));
function takePicture(options) {
    return new Promise(function (resolve, reject) {
        listener = null;
        var simpleCam = SimpleCam.new();
        var reqWidth = 0;
        var reqHeight = 0;
        var keepAspectRatio = true;
        var delegateOption = null;
        if (options) {
            reqWidth = options.width || 0;
            reqHeight = options.height || reqWidth;
            keepAspectRatio = types.isNullOrUndefined(options.keepAspectRatio) ? true : options.keepAspectRatio;
        }
        if (reqWidth && reqHeight) {
            delegateOption = { width: reqWidth, height: reqHeight, keepAspectRatio: keepAspectRatio };
        }
        listener = SimpleCamDelegateImpl.initWithCallbackAndOptions(resolve, delegateOption);
        simpleCam.delegate = listener;
        var topMostFrame = frame.topmost();
        if (topMostFrame) {
            var viewController = topMostFrame.currentPage && topMostFrame.currentPage.ios;
            if (viewController) {
                viewController.presentViewControllerAnimatedCompletion(simpleCam, true, null);
            }
        }
    });
}
exports.takePicture = takePicture;
function isAvailable() {
    return AVCaptureDevice.defaultDeviceWithMediaType(AVMediaTypeVideo) != null;
}
exports.isAvailable = isAvailable;
function requestPermissions() {
    return new Promise(function (resolve, reject) {
        var authStatus = AVCaptureDevice.authorizationStatusForMediaType(AVMediaTypeVideo);
        if (authStatus === 0) {
            AVCaptureDevice.requestAccessForMediaTypeCompletionHandler(AVMediaTypeVideo, function (granted) {
                if (granted) {
                    if (trace.isEnabled()) {
                        trace.write("Application can access AVCaptureDevice.", trace.categories.Debug);
                    }
                    return resolve();
                }
            });
        }
        else if (authStatus !== 3) {
            if (trace.isEnabled()) {
                trace.write("Application can not access AVCaptureDevice.", trace.categories.Debug);
            }
            return reject();
        }
        return resolve();
    });
}
exports.requestPermissions = requestPermissions;
//# sourceMappingURL=nativescript-simplecam.ios.js.map